@@ -43,16 +43,22 @@ ngramTokens<-function(texts,
 
   dgm<-lapply(ngrams, function(x) as.matrix(array(NA, c(length(texts),100))))
   stemtokens<-quanteda::tokens(lapply(cleanertext, stemmer,wstem=wstem,language=language))
-  for (ng in 1:length(ngrams)){
+  for (ng in ngrams){
     if (ng==1) {
       dgm[[ng]] <-quanteda::dfm(stemtokens)
     }else{
       dgm[[ng]] <- quanteda::dfm(quanteda::tokens_ngrams(stemtokens,ng))
     }
     if ((sparse<1)&is.null(vocabmatch)) dgm[[ng]]<-quanteda::dfm_trim(dgm[[ng]],sparsity=sparse)
-    if (ng==1) dtm<-dgm[[1]]
-    if ((ng>1)&(overlap<1)&(!is.null(dim(dgm[[ng]])))) dtm<-overlaps(high=dgm[[ng]],low=dtm,
-                                                                     cutoff=overlap,verbose=verbose)
+    if (ng==ngrams[1]) { dtm<-dgm[[ng]]
+    } else{
+      if ((overlap<1)&(!is.null(dim(dgm[[ng]])))){
+        dtm<-overlaps(high=dgm[[ng]],low=dtm, cutoff=overlap,verbose=verbose)
+      } else {
+        dtm<-cbind(dtm,dgm[[ng]])
+      }
+
+    }
 
     if (verbose) print(paste(c(ng,"-grams ", dim(dtm)),collapse=" "))
   }
